from earthdiagnostics.variable_type import VariableType


class Frequency(object):

    _recognized = {'f': 'fx', 'fx': 'fx', 'fixed': 'fx',
                   'c': 'clim', 'clim': 'clim', 'climatology': 'clim', 'monclim': 'clim', '1hrclimmon': 'clim',
                   'y': 'year', 'yr': 'year', 'year': 'year', 'yearly': 'year',
                   'm': 'mon', 'mon': 'mon', 'monthly': 'mon',
                   'd': 'day', 'daily': 'day', 'day': 'day',
                   '6': '6hr', '6hr': '6hr', '6_hourly': '6hr', '6hourly': '3hr',
                   '3': '3hr', '3hr': '3hr', '3_hourly': '3hr', '3hourly': '3hr',
                   '1': 'hr', 'hr': 'hr', 'hourly': 'hr', '1hr': 'hr',
                   'subhr': 'subhr'}

    def __init__(self, freq):
        freq = freq.lower()
        try:
            self.frequency = Frequency._recognized[freq]
        except KeyError:
            raise Exception('Frequency {0} not supported'.format(freq))

    def __eq__(self, other):
        return self.frequency == other.frequency

    def __str__(self):
        return self.frequency

    def folder_name(self, vartype):
        if self == Frequencies.daily:
            freq_str = 'daily_{0}'.format(VariableType.to_str(vartype))
        elif self == Frequencies.climatology:
            freq_str = 'clim'
        elif self.frequency.endswith('hr'):
            freq_str = self[:-2] + 'hourly'
        else:
            freq_str = 'monthly_{0}'.format(VariableType.to_str(vartype))
        return freq_str

    @staticmethod
    def parse(freq):
        if isinstance(freq, Frequency):
            return freq
        return Frequency(freq)


class Frequencies(object):
    fixed = Frequency('fx')
    climatology = Frequency('clim')
    yearly = Frequency('year')
    monthly = Frequency('mon')
    daily = Frequency('day')
    six_hourly = Frequency('6hr')
    three_hourly = Frequency('3hr')
